@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2024 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,7 +7,6 @@
 #include "addresseelineedit_p.h"
 #include "addresseelineedit.h"
 #include "addresseelineeditmanager.h"
-#include "addressline/completionorder/completionordereditor.h"
 #include "kmailcompletion.h"
 #include "pimcommonakonadi_debug.h"
 
@@ -83,6 +82,16 @@ public:
     }
 };
 
+void AddresseeLineEditPrivate::setLdapActivitiesAbstract(KLDAPCore::LdapActivitiesAbstract *ldapActivities)
+{
+    mLdapActivities = ldapActivities;
+}
+
+KLDAPCore::LdapActivitiesAbstract *AddresseeLineEditPrivate::ldapActivitiesAbstract() const
+{
+    return mLdapActivities;
+}
+
 void AddresseeLineEditPrivate::init()
 {
     if (mToolButton) {
@@ -93,7 +102,7 @@ void AddresseeLineEditPrivate::init()
     mToolButton->setCursor(Qt::ArrowCursor);
     const int size = q->sizeHint().height() - 5;
     mToolButton->setFixedSize(size, size);
-    int padding = (q->sizeHint().height() - size) / 2;
+    const int padding = (q->sizeHint().height() - size) / 2;
     mToolButton->move(2, padding);
     mToolButton->setStyleSheet(QStringLiteral("QToolButton { border: none; }"));
     connect(mToolButton, &QToolButton::clicked, q, &AddresseeLineEdit::iconClicked);
@@ -147,7 +156,7 @@ void AddresseeLineEditPrivate::searchInBaloo()
 {
 #if !DISABLE_AKONADI_SEARCH
     const QString trimmedString = mSearchString.trimmed();
-    Akonadi::Search::PIM::ContactCompleter com(trimmedString, 20);
+    const Akonadi::Search::PIM::ContactCompleter com(trimmedString, 20);
     const QStringList listEmail = AddresseeLineEditManager::self()->cleanupEmailList(com.complete());
     for (const QString &email : listEmail) {
         addCompletionItem(email, 1, AddresseeLineEditManager::self()->balooCompletionSource());
@@ -632,18 +641,6 @@ void AddresseeLineEditPrivate::slotLDAPSearchData(const KLDAPCore::LdapResult::L
     }
 }
 
-void AddresseeLineEditPrivate::slotEditCompletionOrder()
-{
-    if (mUseCompletion) {
-        init(); // for AddresseeLineEditStatic::self()->ldapSearch
-        QPointer<CompletionOrderEditor> dlg = new CompletionOrderEditor(AddresseeLineEditManager::self()->ldapSearch(), nullptr);
-        if (dlg->exec()) {
-            AddresseeLineEditManager::self()->updateCompletionOrder();
-        }
-        delete dlg;
-    }
-}
-
 KLDAPCore::LdapClientSearch *AddresseeLineEditPrivate::ldapSearch()
 {
     init(); // for AddresseeLineEditStatic::self()->ldapSearch
