@@ -478,7 +478,7 @@ LdapSearchDialog::LdapSearchDialog(QWidget *parent)
     d->user1Button = new QPushButton;
     buttonBox->addButton(d->user1Button, QDialogButtonBox::ActionRole);
 
-    auto user2Button = new QPushButton;
+    auto user2Button = new QPushButton(this);
     buttonBox->addButton(user2Button, QDialogButtonBox::ActionRole);
 
     connect(d->user1Button, &QPushButton::clicked, this, &LdapSearchDialog::slotUser1);
@@ -862,7 +862,7 @@ void LdapSearchDialog::slotUser2()
 
     QPointer<KCMultiDialog> dialog = new KCMultiDialog(this);
     dialog->setWindowTitle(i18nc("@title:window", "Configure the Address Book LDAP Settings"));
-    dialog->addModule(KPluginMetaData(QStringLiteral("pim6/kcms/kaddressbook/kcm_ldap")));
+    dialog->addModule(KPluginMetaData(QStringLiteral("pim6/kcms/common/kcm_ldap")));
 
     if (dialog->exec()) { // krazy:exclude=crashy
         d->restoreSettings();
